import cx from 'clsx';
import { useAtom } from 'jotai';
import { useState } from 'react';
import { ColorPicker } from '../components/ColorPicker';
import { LabeledPicker } from '../components/LabeledPicker';
import { ScrollArea } from '../components/ScrollArea';
import { VSegmentedControl } from '../components/VSegmentedControl';
import { ColorWheel } from '../page-components/wheels/ColorWheel';
import { currentPickedColor } from '../stores/colors';
import styles from './Wheels.module.css';

export function Wheels() {
  const [selectedColor, setSelectedColor] = useAtom(currentPickedColor);
  const [selectedMode, setSelectedMode] = useState('complementary');
  const [steps, setSteps] = useState(10);
  const [tones, setTones] = useState(3);

  return (
    <div className={cx('workspace', styles.wheels_workspace)}>
      <header>
        <h3>Color Wheels</h3>
        <p>Choose the required color on the color wheel according to color theory.</p>
      </header>
      <ScrollArea enableY>
        <section className={styles.explore_section}>
          <aside className={styles.function_side}>
            <div>
              <h5>Basic color</h5>
              <ColorPicker color={selectedColor} onSelect={(color) => setSelectedColor(color)} />
            </div>
            <div>
              <h5>Series Setting</h5>
              <LabeledPicker
                title="Expand Tones"
                min={1}
                max={5}
                step={1}
                value={tones}
                onChange={setTones}
              />
              <LabeledPicker
                title="Tone Step"
                min={5}
                max={50}
                step={1}
                unit="%"
                value={steps}
                onChange={setSteps}
              />
            </div>
            <div className={styles.mode_navigation}>
              <h5>Color selection method</h5>
              <VSegmentedControl
                onChange={setSelectedMode}
                options={[
                  { label: 'Complementary', value: 'complementary' },
                  { label: 'Analogous', value: 'analogous' },
                  { label: 'Analogous with Complementary', value: 'analogous_with_complementary' },
                  { label: 'Triadic', value: 'triadic' },
                  { label: 'Split Complementary', value: 'split_complementary' },
                  { label: 'Tetradic', value: 'tetradic' },
                  { label: 'Flip Tetradic', value: 'flip_tetradic' },
                  { label: 'Square', value: 'square' },
                ]}
              />
            </div>
          </aside>
          <div className={styles.wheel_side}>
            <ColorWheel
              originColor={selectedColor}
              highlightMode={selectedMode}
              tones={tones}
              step={steps}
            />
          </div>
        </section>
      </ScrollArea>
    </div>
  );
}
